@@ -20,9 +20,9 @@ except IOError:
 
 try:
         with open("a_data.txt", "w") as a_file: #change output txt file in your format, such as Susane_data.txt
-                print_lol(man, fh=a_file)
+                print_lol(a, fh=a_file)
         with open("b_data.txt", "w") as b_file: #same here, but other participant
-                print_lol(other, fh=b_file)
+                print_lol(b, fh=b_file)
         
 except IOError as err:
         print("File error: " + str(err))
